@@ -6,7 +6,7 @@ from ..types.objects import Page
 
 class Resources(object):
     """ Page resources.
-        See `sec 7.8.3 Resource Dictionaries <https://www.adobe.com/content/dam/acom/en/devnet/pdf/pdfs/PDF32000_2008.pdf#page=82>`_ """
+        See `sec 7.8.3 Resource Dictionaries <https://opensource.adobe.com/dc-acrobat-sdk-docs/standards/pdfstandards/pdf/PDF32000_2008.pdf#page=82>`_ """
     _fields = ('ExtGState', 'ColorSpace', 'Pattern', 'Shading', 'XObject', 'Font', 'ProcSet', 'Properties')
 
     def __init__(self, **kwargs):
